@@ -248,7 +248,7 @@ def install_collector(collector_name, modules_path, s3_base_collectors_link):
         get_collector_files(collector_name, modules_path, s3_base_collectors_link)
 
     except Exception as e:
-        print ("Failed to load Module: %s. %s" % (e, traceback.format_exc()))
+        print ("Failed to install Collector: %s. %s" % (e, traceback.format_exc()))
 
 
 def get_worker_files(modules_path, s3_base_workers_link, worker_name):
@@ -297,5 +297,6 @@ def handle_prerequisites(s3_base_module_link, module_name):
                 print ("Some prerequisites for this module have not been met. " \
                        "Please install the following before proceeding: " + str(missing_packages))
                 sys.exit(1)
-    except Exception:
+    except Exception as e:
+        print ("Failed to handle prerequisites: %s. %s" % (e, traceback.format_exc()))
         pass
