@@ -1,11 +1,10 @@
 from __future__ import print_function
 
 try:
-    from urllib.parse import quote
     from urllib.request import Request, urlopen
     from urllib.error import HTTPError, URLError
 except:
-    from urllib2 import Request, urlopen, HTTPError, URLError, quote
+    from urllib2 import Request, urlopen, HTTPError, URLError
 
 from future import standard_library
 standard_library.install_aliases()
@@ -45,9 +44,8 @@ def safe_get_json(json_string, key, log=logging.getLogger('spotinst-agent')):
 
 def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.debug("reading simple {} ...".format(quoteUrl))
-        req = Request(quoteUrl)
+        log.debug("reading simple {} ...".format(url))
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         response = urlopen(req, timeout=10)
         return response.read().decode('utf-8')
@@ -66,9 +64,8 @@ def safe_read_simple_url(url, log=logging.getLogger('spotinst-agent')):
 def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
     try:
         url = url + path_params
-        quoteUrl = quote(url)
-        log.debug("reading simple {} ...".format(quoteUrl))
-        req = Request(quoteUrl)
+        log.debug("reading simple {} ...".format(url))
+        req = Request(url)
         #req.add_header('Content-Type', 'application/json')
         req.add_header('Metadata-Flavor','Google')
         response = urlopen(req, timeout=10)
@@ -88,9 +85,8 @@ def get_gcp_metadata(url, path_params, log=logging.getLogger('spotinst-agent')):
 # getting vmId - not whole the metadata
 def get_azure_metadata(url, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.debug("reading simple {} ...".format(quoteUrl))
-        req = Request(quoteUrl)
+        log.debug("reading simple {} ...".format(url))
+        req = Request(url)
         req.add_header('Metadata', 'true')
         response = urlopen(req, timeout=10)
         return response.read().decode('utf-8')
@@ -109,9 +105,8 @@ def get_azure_metadata(url, log=logging.getLogger('spotinst-agent')):
 
 def safe_get_simple_url(url, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.debug("reading simple {} ...".format(quoteUrl))
-        req = Request(quoteUrl)
+        log.debug("reading simple {} ...".format(url))
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         response = urlopen(req, timeout=5)
         res = response.read()
@@ -131,9 +126,8 @@ def safe_get_simple_url(url, log=logging.getLogger('spotinst-agent')):
 
 def safe_get_url(url, token=None, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.debug("getting {} ...".format(quoteUrl))
-        req = Request(quoteUrl)
+        log.debug("getting {} ...".format(url))
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
@@ -159,11 +153,10 @@ def safe_get_url(url, token=None, log=logging.getLogger('spotinst-agent')):
 
 def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.info("posting {} ...".format(quoteUrl))
+        log.info("posting {} ...".format(url))
         log.info("token is " + token)
         data = message.encode('utf-8')
-        req = Request(quoteUrl)
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
@@ -191,10 +184,9 @@ def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agen
 
 def safe_put_url(url, message, token, log=logging.getLogger('spotinst-agent')):
     try:
-        quoteUrl = quote(url)
-        log.debug("putting %s ..." % quoteUrl)
+        log.debug("putting %s ..." % url)
         data = message.encode('utf-8')
-        req = Request(quoteUrl)
+        req = Request(url)
         req.add_header('Content-Type', 'application/json')
         if token:  # add token
             req.add_header('Authorization', 'Bearer ' + token)
